/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: trap.h,v 1.35 2007/11/06 03:17:59 bowkenken Exp $
***************************************************************/

#ifndef	TRAP_H
#define	TRAP_H

/***************************************************************
* 
***************************************************************/

#include	"gmain.h"
#include	"msg.h"

/***************************************************************
* ǥХåѥå
***************************************************************/

/* 1 ˤ櫤̤ˤĤ(ǥХå) */

#if	0
# ifndef	D_TEST_TRAP
#  define	D_TEST_TRAP
# endif
#endif

#ifdef	D_TEST_TRAP
# define	TRAP_AVE_N	512
# define	TRAP_MAX_N	1024
#else
# define	TRAP_AVE_N	12
# define	TRAP_MAX_N	128
#endif

/***************************************************************
* 櫤μ
***************************************************************/

typedef enum {
	TRAP_KIND_NULL,
	/* ̲ */
	TRAP_KIND_SLEEP,
	/*  */
	TRAP_KIND_ARW,
	/* ǥĤ */
	TRAP_KIND_POISON_DARTS,
	/* Ƥ */
	TRAP_KIND_BOMB,
	/* ѡƥְִư */
	TRAP_KIND_TELEPORT_PARTY,
	/* ְִư */
	TRAP_KIND_TELEPORT,
	/*  */
	TRAP_KIND_PIT,
	/* 塼 */
	TRAP_KIND_CHUTE,
	/*  */
	TRAP_KIND_SANCTUARY,
	TRAP_KIND_MAX_N
} trap_kind_t;

/***************************************************************
* 櫤Υǡơ֥
***************************************************************/

typedef struct {
	/*  */
	trap_kind_t	kind;
	/* ̾ ID */
	n_msg_t	name_n;
	/* ̾ */
	char	*name;
	/* иΨ */
	rate_t	rate;
	/* ޥʡʸ */
	char	mnr;
	/* и */
	long	min_lev, max_lev, sgn_lev;
	/* åɽ뤫? */
	bool_t	flg_draw_msg;
} trap_tab_t;

/***************************************************************
* 櫤Υǡ
***************************************************************/

typedef struct trap_t {
	/* 󥯡ݥ */
	struct trap_t	*next, *prev;

	/*  */
	trap_kind_t	kind;
	/* ɸ */
	long	x, y;

	/* 櫤Υ٥ */
	long	lev;
	/* 񤷤 */
	long	difficulty;
	/* Ĵ٤Ƥ뤫? */
	bool_t	flg_chked;
	/* 櫤濴ؤкɸ */
	bool_t	cx, cy;

	/* ǡơ֥ */
	trap_tab_t	*tab;
} trap_t;

#endif	/* TRAP_H */
